ChalonaComponent class abstract

ChalonaComponent - Clase base que implementa el patrón de inicialización en dos fases similar a FoxPro, con métodos load() e init()

Constructors

ChalonaComponent()
Constructor que ejecuta la secuencia de inicialización

Properties

hashCode int
The hash code for this object.
no setterinherited
isInitialized bool
no setter
isLoaded bool
Getters para verificar el estado de inicialización
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ensureInitialized() → void
Método para forzar la inicialización si no se ha realizado
init() → void
Método init() - Se ejecuta después de la construcción de componentes Override este método para inicialización tardía
load() → void
Método load() - Se ejecuta antes de la construcción de componentes Override este método para inicialización temprana
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited