ChalonaMultiselect class abstract

Inheritance

Constructors

ChalonaMultiselect({String? name, bool free = false})

Properties

hasChanges bool
Verifica si hay cambios comparando el valor actual con el inicial
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
initial List<String>
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
isStandalone bool
finalinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value List<String>
Propiedad value que retorna el contenido usando get()
getter/setter pairinherited

Methods

changes(Map<String, dynamic> changesMap) bool
inherited
compareTo(dynamic other) int
Compares this object to another object.
inherited
contains(String element) bool
Verificar si la lista contiene un elemento específico
inherited
from(dynamic value) List<String>
inherited
get() List<String>
override
getList() Map<String, ChalonaSelectable>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset([dynamic v]) → void
override
set(dynamic v) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited