ChalonaPsqlConnection class
- Inheritance
-
- Object
- ChalonaHost<
ChalonaResponse> - ChalonaSqlConnection
- ChalonaPsqlConnection
Constructors
- ChalonaPsqlConnection({required String host})
Properties
- database ↔ String
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- host ↔ String
-
latefinal
- listenConnection ↔ Connection?
-
getter/setter pair
- listenList ↔ Map
-
getter/setter pair
- port ↔ int
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema ↔ dynamic
-
latefinal
- user ↔ String
-
latefinal
- wsServer ↔ ChalonaSocketIOServer
-
getter/setter pairinherited
Methods
-
forWSConnect(
ChalonaSocketIO ws) → void -
listen(
String channel, dynamic fn(String msg)) → dynamic -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
String cstring, {Map data = const {}, String? token, List< ChalonaFile> files = const []}) → Future<ChalonaResponse> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
transaction(
TransactionFn fn) → Future< ChalonaResponse> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited