DescuentosORecargosInstance class

Inheritance

Properties

first DescuentoORecargo
Obtener el primer elemento sin removerlo
no setterinherited
firstOrNull DescuentoORecargo?
Obtener el primer elemento o null si la lista está vacía
no setterinherited
hasChanges bool
Verifica si hay cambios comparando el valor actual con el inicial
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
Verificar si la lista está vacía
no setterinherited
isStandalone bool
finalinherited
items Iterable<DescuentoORecargo>
no setterinherited
last DescuentoORecargo
Obtener el último elemento sin removerlo
no setterinherited
lastOrNull DescuentoORecargo?
Obtener el último elemento o null si la lista está vacía
no setterinherited
length int
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(dynamic item) → void
Agregar un elemento a la lista
inherited
addAll(dynamic items) → void
Agregar múltiples elementos a la lista
inherited
addFirst(dynamic item) → void
Agregar elementos al inicio de la lista
inherited
addLast(dynamic item) → void
Agregar elementos al final de la lista (alias de add)
inherited
changes(Map<String, dynamic> changesMap) bool
Verificar si hay cambios en alguno de los elementos de la lista
inherited
clear() → void
Limpiar todos los elementos de la lista
inherited
contains(dynamic element) bool
Verificar si contiene un elemento
inherited
elementAt(int index) DescuentoORecargo
Obtener el elemento en una posición específica con valor por defecto
inherited
elementAtOrNull(int index) DescuentoORecargo?
Obtener el elemento en una posición específica o null si está fuera de rango
inherited
get() List<Map<String, dynamic>>
inherited
getOrDefault(int index, DescuentoORecargo defaultValue) DescuentoORecargo
Obtener el elemento en una posición específica o un valor por defecto
inherited
getOrElse(int index, DescuentoORecargo defaultValue()) DescuentoORecargo
Obtener el elemento en una posición específica o un valor por defecto
inherited
indexOf(dynamic element, [int start = 0]) int
Obtener el índice del primer elemento que coincida
inherited
insert(int index, dynamic item) → void
Insertar un elemento en una posición específica
inherited
insertAll(int index, dynamic items) → void
Insertar múltiples elementos en una posición específica
inherited
lastIndexOf(dynamic element, [int? start]) int
Obtener el índice del último elemento que coincida
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(dynamic item) bool
Remover el primer elemento que coincida con el criterio
inherited
removeAt(int index) DescuentoORecargo
Remover el elemento en la posición especificada
inherited
removeFirst() DescuentoORecargo
Remover el primer elemento de la lista
inherited
removeLast() DescuentoORecargo
Remover el último elemento de la lista
inherited
removeRange(int start, int end) → void
Remover elementos en un rango específico
inherited
removeWhere(bool test(DescuentoORecargo element)) → void
Remover elementos que cumplan con una condición
inherited
reset([dynamic value]) → void
inherited
retainWhere(bool test(DescuentoORecargo element)) → void
Mantener solo los elementos que cumplan con una condición
inherited
set(dynamic value) → void
inherited
setAll(int index, dynamic items) → void
Reemplazar todos los elementos
inherited
setRange(int start, int end, dynamic items, [int skipCount = 0]) → void
Reemplazar elementos en un rango específico
inherited
sublist(int start, [int? end]) List<DescuentoORecargo>
Obtener un subconjunto de la lista
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) DescuentoORecargo?
inherited
operator []=(int index, dynamic value) → void
Establecer el elemento en una posición específica
inherited