ChalonaApp<T extends ChalonaSession> class

Inheritance
Implementers

Constructors

ChalonaApp({required String name, required String title, required String host, required T session, required Future<ChalonaSocketIO> wsConnect(), Widget splash(BuildContext context)?, Widget login(BuildContext context)?, Widget onErrorLoading(BuildContext context)?, void onSuccess(BuildContext context, String msg)?, void onError(BuildContext context, String msg)?, Map<String, Widget Function(BuildContext)> routes = const {}})

Properties

defs ChalonaDefs
finalinherited
hashCode int
The hash code for this object.
no setterinherited
host ChalonaHost<ChalonaResponse>
Indica si el servidor ya fue inicializado Conexión a la base de datos
finalinherited
name String
final
routes → dynamic
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session ↔ T
getter/setter pair
state ChalonaState
latefinalinherited
title String
final
wsConnect Future<ChalonaSocketIO> Function()
finalinherited
wsServer ChalonaSocketIOServer
getter/setter pairinherited

Methods

error(String msg) → void
Muestra un mensaje de error
initialize() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on({required String route, required ChalonaResponse fn(ChalonaRequest req)}) → void
inherited
request(String path, {Map? data, String? token, List<ChalonaFile> files = const []}) Future<ChalonaResponse>
Realiza el proceso de login
override
resetToRoot() → void
Vuelve a la raíz de la aplicación y limpia la pila de navegación
startApp() Widget
Inicia la aplicación y maneja el flujo de autenticación
startServer() Future<bool>
Inicia el servidor y carga la sesión
override
success(String msg) → void
Muestra un mensaje de éxito
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

appIsLoaded() bool