ChalonaDynamicMap<T extends ChalonaType> class

ChalonaDynamicMap El tipo para manejo de Map<String, T> dinámico

Mixed-in types
Implementers

Constructors

ChalonaDynamicMap({required String name, required T builder()})

Properties

builder ↔ T Function()
getter/setter pair
changed bool
no setterinherited
entries Iterable<MapEntry<String, T>>
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setteroverride
isNotEmpty bool
no setteroverride
keys Iterable<String>
no setter
length int
no setter
name String
latefinalinherited
parent ChalonaType?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ↔ dynamic
latefinalinherited
values Iterable<T>
no setter

Methods

addEntry(String key, T value) → void
changes(Map x) bool
override
clear() → void
containsKey(String key) bool
forEach(void action(String key, T value)) → void
get() → dynamic
override
mapValues<R>(R mapper(String key, T value)) Map<String, R>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → T?
reset([dynamic v]) → dynamic
override
set(dynamic v) → dynamic
override
toString() String
A string representation of this object.
inherited
undo() → dynamic
override
valid([dynamic x]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) → T?
operator []=(String key, T value) → void