ChalonaMapValue<K, V> class

Mixed-in types
Implementers

Constructors

ChalonaMapValue({required String name})

Properties

changed bool
no setterinherited
dfault Map<K, V>
getter/setter pair
entries Iterable<MapEntry<K, V>>
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setteroverride
isNotEmpty bool
no setteroverride
keys Iterable<K>
no setter
length int
no setter
name String
latefinalinherited
parent ChalonaType?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ↔ dynamic
latefinalinherited
values Iterable<V>
no setter

Methods

addAll(Map<K, V> other) → void
changes(Map x) bool
override
clear() → void
containsKey(K key) bool
forEach(void action(K key, V value)) → void
get() → dynamic
override
map<R>(R transform(K key, V value)) Map<K, R>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(K key) → V?
reset([Map? v]) → dynamic
override
set(dynamic map) → dynamic
override
toString() String
A string representation of this object.
inherited
undo() → dynamic
override
valid([dynamic x]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](K key) → V?
operator []=(K key, V value) → void