ChalonaValue<T> class abstract

ChalonaValue El tipo abstracto para manejo de datos no compuestos como string, bool, int, double o date

Mixed-in types
Implementers
Available extensions

Constructors

ChalonaValue({required String name, required T dfault})

Properties

changed bool
no setterinherited
dfault ↔ T
getter/setter pair
hashCode int
Hash code para usar en colecciones
no setteroverride
initial → T
no setter
isEmpty bool
no setteroverride
isNotEmpty bool
no setterinherited
last → T
no setter
name String
latefinalinherited
parent ChalonaType?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ↔ dynamic
latefinalinherited
value ↔ T
getter/setter pair

Methods

changes(Map x) bool
override
compareTo(dynamic other) int
Compara dos valores del mismo tipo Retorna: -1 si this < other 0 si this == other 1 si this > other
from(dynamic v) → T
get() → dynamic
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset([dynamic v]) → dynamic
override
set(dynamic value) → dynamic
override
toString() String
A string representation of this object.
inherited
toXml({String codigoSeguridadParaGenerarRFCE = ''}) String

Available on ChalonaType, provided by the toXmlExtension extension

undo() → dynamic
override
valid([dynamic x]) bool
inherited

Operators

operator <(dynamic other) bool
Operador menor que
operator <=(dynamic other) bool
Operador menor o igual que
operator ==(Object other) bool
Operador de igualdad
override
operator >(dynamic other) bool
Operador mayor que
operator >=(dynamic other) bool
Operador mayor o igual que