ChalonaSqlHost<T extends ChalonaSqlConnection> class

Inheritance
Implementers

Constructors

ChalonaSqlHost({required ChalonaSqlConnection connection})

Properties

connection ChalonaSqlConnection
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wsServer ChalonaSocketIOServer
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request(String path, {Map data = const {}, String? token, List<ChalonaFile> files = const []}) Future<ChalonaResponse>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited