ChalonaDatoDefsMap class

Inheritance

Constructors

ChalonaDatoDefsMap()

Properties

builder ChalonaDatoDefs Function()
getter/setter pairinherited
changed bool
no setterinherited
entries Iterable<MapEntry<String, ChalonaDatoDefs>>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
keys Iterable<String>
no setterinherited
length int
no setterinherited
name String
latefinalinherited
parent ChalonaType?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ↔ dynamic
latefinalinherited
values Iterable<ChalonaDatoDefs>
no setterinherited

Methods

addEntry(String key, ChalonaDatoDefs value) → void
inherited
changes(Map x) bool
inherited
clear() → void
inherited
containsKey(String key) bool
inherited
forEach(void action(String key, ChalonaDatoDefs value)) → void
inherited
get() → dynamic
inherited
mapValues<R>(R mapper(String key, ChalonaDatoDefs value)) Map<String, R>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) ChalonaDatoDefs?
inherited
reset([dynamic v]) → dynamic
inherited
set(dynamic v) → dynamic
inherited
toString() String
A string representation of this object.
inherited
undo() → dynamic
inherited
valid([dynamic x]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) ChalonaDatoDefs?
inherited
operator []=(String key, ChalonaDatoDefs value) → void
inherited