ChalonaDefs class

Inheritance

Constructors

ChalonaDefs({required _ChalonaUnlockedConstructor unlocked})
ChalonaDefs.builder()
factory

Properties

aplicaciones ChalonaAppDefsMap
final
changed bool
no setterinherited
datos ChalonaDatoDefsMap
final
funciones ChalonaFuncionDefsMap
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
key String?
no setterinherited
labels ChalonaLabelDefsMap
final
members Map<String, ChalonaType>
no setterinherited
modulos ChalonaModuloDefsMap
final
name String
latefinalinherited
parent ChalonaType?
no setterinherited
permisos ChalonaPerfilesPermisosMap
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablas ChalonaTableDefsMap
final
type ↔ dynamic
latefinalinherited

Methods

changes(Map x) bool
inherited
get() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset([Map? value]) → dynamic
inherited
restore({bool force = false}) → dynamic
set(dynamic v) → dynamic
inherited
startUpdateService() → dynamic
toString() String
A string representation of this object.
inherited
undo() → dynamic
inherited
valid([dynamic x]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited