ChalonaLangDefs class

Inheritance

Constructors

ChalonaLangDefs({required String name})
ChalonaLangDefs.builder({required String name})
factory

Properties

changed bool
no setterinherited
dfault Map<String, String>
getter/setter pairinherited
entries Iterable<MapEntry<String, String>>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
keys Iterable<String>
no setterinherited
length int
no setterinherited
name String
latefinalinherited
parent ChalonaType?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ↔ dynamic
latefinalinherited
values Iterable<String>
no setterinherited

Methods

addAll(Map<String, String> other) → void
inherited
changes(Map x) bool
inherited
clear() → void
inherited
containsKey(String key) bool
inherited
forEach(void action(String key, String value)) → void
inherited
get() → dynamic
inherited
map<R>(R transform(String key, String value)) Map<String, R>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) String?
inherited
reset([Map? v]) → dynamic
inherited
set(dynamic map) → dynamic
inherited
toString() String
A string representation of this object.
inherited
undo() → dynamic
inherited
valid([dynamic x]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) String?
inherited
operator []=(String key, String value) → void
inherited