ChalonaPerfilesPermisosMap class
- Inheritance
-
- Object
- ChalonaDynamicMap<
ChalonaPerfilesPermisos> - ChalonaPerfilesPermisosMap
Constructors
Properties
- builder ↔ ChalonaPerfilesPermisos Function()
-
getter/setter pairinherited
- changed → bool
-
no setterinherited
-
entries
→ Iterable<
MapEntry< String, ChalonaPerfilesPermisos> > -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setterinherited
- isNotEmpty → bool
-
no setterinherited
-
keys
→ Iterable<
String> -
no setterinherited
- length → int
-
no setterinherited
- name ↔ String
-
latefinalinherited
- parent → ChalonaType?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ dynamic
-
latefinalinherited
-
values
→ Iterable<
ChalonaPerfilesPermisos> -
no setterinherited
Methods
-
addEntry(
String key, ChalonaPerfilesPermisos value) → void -
inherited
-
changes(
Map x) → bool -
inherited
-
clear(
) → void -
inherited
-
containsKey(
String key) → bool -
inherited
-
forEach(
void action(String key, ChalonaPerfilesPermisos value)) → void -
inherited
-
get(
) → dynamic -
inherited
-
isGranted(
String user, String empresa, String fn) → bool -
mapValues<
R> (R mapper(String key, ChalonaPerfilesPermisos value)) → Map< String, R> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String key) → ChalonaPerfilesPermisos? -
inherited
-
reset(
[dynamic v]) → dynamic -
inherited
-
set(
dynamic v) → dynamic -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
undo(
) → dynamic -
inherited
-
valid(
[dynamic x]) → bool -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → ChalonaPerfilesPermisos? -
inherited
-
operator []=(
String key, ChalonaPerfilesPermisos value) → void -
inherited