ChalonaFile class

Inheritance

Constructors

ChalonaFile({required String fileName, String filePath = '', required String content, String? name})

Properties

content String
finalinherited
fileName String
finalinherited
filePath String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getFile() Future<List<ChalonaFile>>