ChalonaResponse class

Constructors

ChalonaResponse({MapType? source})
ChalonaResponse.error(String msg, MapType data)
factory

Properties

data MapType
no setter
hashCode int
The hash code for this object.
no setterinherited
lang String
no setter
msg String
no setter
ok bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited
translateTo(String lang) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited