ChalonaServer class

Servidor principal que maneja:

  • Validación de rutas y permisos
  • Gestión de sesiones y autenticación
  • Procesamiento de solicitudes a la base de datos
  • Manejo de errores y respuestas
Inheritance
Implementers

Constructors

ChalonaServer({required ChalonaHost<ChalonaResponse> host, required Future<ChalonaSocketIO> wsConnect(), List<String> newStates = const []})

Properties

defs ChalonaDefs
final
hashCode int
The hash code for this object.
no setterinherited
host ChalonaHost<ChalonaResponse>
Indica si el servidor ya fue inicializado Conexión a la base de datos
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ChalonaState
latefinal
wsConnect Future<ChalonaSocketIO> Function()
final
wsServer ChalonaSocketIOServer
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on({required String route, required ChalonaResponse fn(ChalonaRequest req)}) → void
request(String path, {Map? data, List<ChalonaFile> files = const []}) Future<ChalonaResponse>
override
startServer() Future<bool>
Inicializa el servidor y carga las definiciones Se ejecuta una sola vez y las demás llamadas esperan a que termine
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current ChalonaServer
no setter
dataIsLoadingState String
final
dataLoadingError String
final
dataLoadingIsCompleteState String
final
noStartedState String
final