ChalonaSocketService class

Inheritance

Constructors

ChalonaSocketService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

emit(String channel, dynamic data) → dynamic
inherited
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String channel, dynamic fn(dynamic)) Function
inherited
onClose(dynamic fn(dynamic)) → dynamic
inherited
onError(dynamic fn(dynamic)) → dynamic
inherited
onNotifyState(Function fn) → dynamic
requestState() → dynamic
start() → dynamic
stop() → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited