ChalonaSession class

Inheritance

Constructors

ChalonaSession({required _ChalonaUnlockedConstructor unlocked, required String app, required String project})
ChalonaSession.builder({required String app, required String project})
factory

Properties

app String
final
changed bool
no setterinherited
empresa ChalonaEmpresa
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
isLogued bool
no setter
isNotEmpty bool
no setterinherited
key String?
no setterinherited
members Map<String, ChalonaType>
no setterinherited
name String
latefinalinherited
onReleaseSession ChalonaEvent<Function>
final
onStartSession ChalonaEvent<Function>
final
parent ChalonaType?
no setterinherited
project String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ↔ dynamic
latefinalinherited
user ChalonaUser
final

Methods

changes(Map x) bool
inherited
get() → dynamic
inherited
login({required String user, required String pass}) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() Future<void>
reset([Map? value]) → dynamic
inherited
restore() → dynamic
set(dynamic v) → dynamic
inherited
toString() String
A string representation of this object.
inherited
undo() → dynamic
inherited
valid([dynamic x]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited