DescuentoORecargo class

Inheritance

Constructors

DescuentoORecargo({required _ChalonaUnlockedConstructor unlocked})
DescuentoORecargo.builder()
factory

Properties

changed bool
no setterinherited
DescripcionDescuentooRecargo ChalonaString
final
hashCode int
The hash code for this object.
no setterinherited
IndicadorFacturacionDescuentooRecargo EcfInt
final
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
key String?
no setterinherited
members Map<String, ChalonaType>
no setterinherited
MontoDescuentooRecargo EcfValor
final
name String
latefinalinherited
NumeroLinea ChalonaInt
final
parent ChalonaType?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
TipoAjuste ChalonaString
final
TipoValor ChalonaString
final
type ↔ dynamic
latefinalinherited
ValorDescuentooRecargo EcfValor
final

Methods

changes(Map x) bool
inherited
get() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset([Map? value]) → dynamic
inherited
set(dynamic v) → dynamic
inherited
toString() String
A string representation of this object.
inherited
undo() → dynamic
inherited
valid([dynamic x]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited