Ecf class

Inheritance

Constructors

Ecf({required _ChalonaUnlockedConstructor unlocked})
Ecf.builder()
factory
Ecf.fromJson({required String cert, required String pass, required String json})
factory
Ecf.fromMap(Map<String, dynamic> data)
factory

Properties

changed bool
no setterinherited
DescuentosORecargos DescuentosORecargosInstance
final
DetallesItems DetallesItemsInstance
final
Encabezado EncabezadoInstance
final
FechaHoraFirma ChalonaString
final
generarRFCE bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
InformacionReferencia InformacionReferenciaInstance
final
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
isRFCE bool
no setter
key String?
no setterinherited
members Map<String, ChalonaType>
no setterinherited
name String
getter/setter pairinherited-setteroverride-getter
parent ChalonaType?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ↔ dynamic
latefinalinherited

Methods

changes(Map x) bool
inherited
codigoSeguridad({required String xmlSigned}) String
get() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset([Map? value]) → dynamic
inherited
set(dynamic v) → dynamic
inherited
timbre({required String portal, required String xmlSigned}) String
toString() String
A string representation of this object.
inherited
undo() → dynamic
inherited
valid([dynamic x]) bool
override

Operators

operator ==(Object other) bool
The equality operator.
inherited