EcfInt class

Inheritance

Constructors

EcfInt({required String name, int dfault = 0})

Properties

changed bool
no setterinherited
dfault int
getter/setter pairinherited
hashCode int
Hash code para usar en colecciones
no setterinherited
initial int
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
last int
no setterinherited
name String
latefinalinherited
parent ChalonaType?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ↔ dynamic
latefinalinherited
value int
getter/setter pairinherited

Methods

changes(Map x) bool
inherited
compareTo(dynamic other) int
Compara dos valores del mismo tipo Retorna: -1 si this < other 0 si this == other 1 si this > other
inherited
from(dynamic v) int
inherited
get() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset([dynamic v]) → dynamic
inherited
set(dynamic value) → dynamic
inherited
toString() String
A string representation of this object.
inherited
undo() → dynamic
inherited
valid([dynamic x]) bool
inherited

Operators

operator <(dynamic other) bool
Operador menor que
inherited
operator <=(dynamic other) bool
Operador menor o igual que
inherited
operator ==(Object other) bool
Operador de igualdad
inherited
operator >(dynamic other) bool
Operador mayor que
inherited
operator >=(dynamic other) bool
Operador mayor o igual que
inherited