IdDocInstance class

Inheritance

Constructors

IdDocInstance({required _ChalonaUnlockedConstructor unlocked})
IdDocInstance.builder()
factory

Properties

BancoPago ChalonaString
final
changed bool
no setterinherited
eNCF ChalonaString
final
FechaLimitePago ChalonaString
final
FechaVencimientoSecuencia ChalonaString
final
hashCode int
The hash code for this object.
no setterinherited
IndicadorMontoGravado ChalonaString
final
IndicadorNotaCredito ChalonaString
final
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
key String?
no setterinherited
members Map<String, ChalonaType>
no setterinherited
name String
latefinalinherited
NumeroCuentaPago ChalonaString
final
parent ChalonaType?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
TablaFormasPago TablaFormasPagoInstance
final
TerminoPago ChalonaString
final
TipoCuentaPago ChalonaString
final
TipoeCF ChalonaString
final
TipoIngresos ChalonaString
final
TipoPago ChalonaString
final
type ↔ dynamic
latefinalinherited

Methods

changes(Map x) bool
inherited
get() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset([Map? value]) → dynamic
inherited
set(dynamic v) → dynamic
inherited
toString() String
A string representation of this object.
inherited
undo() → dynamic
inherited
valid([dynamic x]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited