Item class

Inheritance

Constructors

Item({required _ChalonaUnlockedConstructor unlocked})
Item.builder()
factory

Properties

CantidadItem ChalonaString
final
CantidadReferencia ChalonaString
final
changed bool
no setterinherited
DescripcionItem ChalonaString
final
DescuentoMonto EcfValor
final
FechaElaboracion ChalonaString
final
FechaVencimientoItem ChalonaString
final
GradosAlcohol EcfValor
final
hashCode int
The hash code for this object.
no setterinherited
IndicadorBienoServicio EcfInt
final
IndicadorFacturacion EcfInt
final
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
key String?
no setterinherited
members Map<String, ChalonaType>
no setterinherited
MontoItem EcfValor
final
name String
latefinalinherited
NombreItem ChalonaString
final
NumeroLinea EcfInt
final
parent ChalonaType?
no setterinherited
PrecioUnitarioItem ChalonaString
final
PrecioUnitarioReferencia ChalonaString
final
RecargoMonto EcfValor
final
Retencion RetencionInstance
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
TablaCodigosItem TablaCodigosItemInstance
final
TablaImpuestoAdicional TablaImpuestoAdicionalInstance
final
TablaSubcantidad TablaSubcantidadInstance
final
TablaSubDescuento TablaSubDescuentoInstance
final
TablaSubRecargo TablaSubRecargoInstance
final
type ↔ dynamic
latefinalinherited
UnidadMedida ChalonaString
final
UnidadReferencia ChalonaString
final

Methods

changes(Map x) bool
inherited
get() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset([Map? value]) → dynamic
inherited
set(dynamic v) → dynamic
inherited
toString() String
A string representation of this object.
inherited
undo() → dynamic
inherited
valid([dynamic x]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited