SubRecargo class

Inheritance

Constructors

SubRecargo({required _ChalonaUnlockedConstructor unlocked})
SubRecargo.builder()
factory

Properties

changed bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
key String?
no setterinherited
members Map<String, ChalonaType>
no setterinherited
MontoSubRecargo ChalonaString
final
name String
latefinalinherited
parent ChalonaType?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
SubRecargoPorcentaje ChalonaString
final
TipoSubRecargo ChalonaString
final
type ↔ dynamic
latefinalinherited

Methods

changes(Map x) bool
inherited
get() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset([Map? value]) → dynamic
inherited
set(dynamic v) → dynamic
inherited
toString() String
A string representation of this object.
inherited
undo() → dynamic
inherited
valid([dynamic x]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited