TotalesInstance class

Inheritance

Constructors

TotalesInstance({required _ChalonaUnlockedConstructor unlocked})
TotalesInstance.builder()
factory

Properties

changed bool
no setterinherited
descuento_global_porcentaje EcfValor
final
hashCode int
The hash code for this object.
no setterinherited
ImpuestosAdicionales ImpuestosAdicionalesInstance
final
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
ITBIS1 EcfInt
final
ITBIS2 EcfInt
final
ITBIS3 EcfInt
final
key String?
no setterinherited
members Map<String, ChalonaType>
no setterinherited
MontoAvancePago EcfValor
final
MontoExento EcfValor
final
MontoGravadoI1 EcfValor
final
MontoGravadoI2 EcfValor
final
MontoGravadoI3 EcfValor
final
MontoGravadoTotal EcfValor
final
MontoImpuestoAdicional EcfValor
final
MontoNoFacturable EcfValor
final
MontoPeriodo EcfValor
final
MontoTotal EcfValor
final
name String
latefinalinherited
parent ChalonaType?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
SaldoAnterior EcfValor
final
TotalISRRetencion EcfValor
final
TotalITBIS EcfValor
final
TotalITBIS1 EcfValor
final
TotalITBIS2 EcfValor
final
TotalITBIS3 EcfValor
final
TotalITBISRetenido EcfValor
final
type ↔ dynamic
latefinalinherited
ValorPagar EcfValor
final

Methods

changes(Map x) bool
inherited
get() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset([Map? value]) → dynamic
inherited
set(dynamic v) → dynamic
inherited
toString() String
A string representation of this object.
inherited
undo() → dynamic
inherited
valid([dynamic x]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited