ChalonaMap class
ChalonaMap El tipo abstracto para manejo de datos con miembros tipo Map
- Mixed-in types
-
- ChalonaType<
Map< String, dynamic> >
- ChalonaType<
- Implementers
- ChalonaDefs
- ChalonaDefsBase
- ChalonaEmpresa
- ChalonaEmpresaPermisos
- ChalonaSession
- ChalonaUser
- CodigosItem
- CompradorInstance
- DescuentoORecargo
- Ecf
- EmisorInstance
- EncabezadoInstance
- FormaDePago
- IdDocInstance
- ImpuestoAdicional
- InformacionReferenciaInstance
- Item
- RetencionInstance
- SubcantidadItem
- SubDescuento
- SubRecargo
- TotalesInstance
Constructors
- ChalonaMap({required _ChalonaUnlockedConstructor unlocked, required String name})
Properties
- changed → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setteroverride
- isNotEmpty → bool
-
no setterinherited
- key → String?
-
no setter
-
members
→ Map<
String, ChalonaType> -
no setter
- name ↔ String
-
latefinalinherited
- parent → ChalonaType?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ dynamic
-
latefinalinherited
Methods
-
changes(
Map x) → bool -
override
-
get(
) → dynamic -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
[Map? value]) → dynamic -
override
-
set(
dynamic v) → dynamic -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
undo(
) → dynamic -
override
-
valid(
[dynamic x]) → bool -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
builder<
T> (T fn(_ChalonaUnlockedConstructor unlocked)) → dynamic