ChalonaSqlConnection class abstract
- Inheritance
-
- Object
- ChalonaHost<
ChalonaResponse> - ChalonaSqlConnection
- Implementers
Constructors
- ChalonaSqlConnection({required String host})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wsServer ↔ ChalonaSocketIOServer
-
getter/setter pairinherited
Methods
-
listen(
String channel, dynamic fn(String msg)) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
String path, {Map data = const {}, String? token, List< ChalonaFile> files = const []}) → Future<ChalonaResponse> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
transaction(
TransactionFn fn) → Future< ChalonaResponse>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited