ChalonaService class abstract
Clase base para todos los servicios Chalona
- Implementers
Constructors
Properties
- active ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- io ↔ ChalonaSocketIO
-
latefinal
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → ChalonaSession
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyState(
{String? descrip, required String detail}) → void - Notifica un estado del servicio
-
onRequestState(
Function fn) → dynamic -
onStart(
Function fn) → dynamic -
onStop(
Function fn) → dynamic -
restoreSession(
) → dynamic -
start(
) → Future< void> - Método que debe implementar cada servicio para inicializarse
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited