ChalonaState class
Clase que maneja el estado y progreso de inicialización de la aplicación
Constructors
-
ChalonaState({required List<
String> states})
Properties
- currentLevel → int
-
no setter
- descrip → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- levelCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- started → bool
-
no setter
- starting → bool
-
no setter
-
states
→ List<
String> -
no setter
-
stream
→ Stream<
String> -
no setter
Methods
-
error(
String error) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
-
update(
String state) → dynamic
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited