ChalonaStorage class abstract
Clase base que puede ser extendida por las diferentes implementaciones
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
String name, {dynamic defaultValue}) → Future -
Obtiene un valor del almacenamiento
name- Nombre de la clavedefaultValue- Valor por defecto si no existe -
getMap(
String name, {Map defaultValue = const {}}) → Future< Map> -
Obtiene un mapa del almacenamiento
name- Nombre de la clavedefaultValue- Valor por defecto si no existe -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
String name, dynamic value) → Future -
Guarda un valor en el almacenamiento
name- Nombre de la clavevalue- Valor a guardar -
setAll(
Map< String, dynamic> value) → Future -
Guarda múltiples valores en el almacenamiento
value- Mapa de valores a guardar -
setMap(
String name, Map value) → Future -
Guarda un mapa en el almacenamiento
name- Nombre de la clavevalue- Mapa a guardar -
toString(
) → String -
A string representation of this object.
inherited
-
unset(
String name) → Future -
Elimina un valor del almacenamiento
name- Nombre de la clave a eliminar
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- current ↔ ChalonaStorage?
-
getter/setter pair